=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2012-01-06 01:42:16 +0000
+++ bzrlib/mutabletree.py	2012-01-06 01:58:27 +0000
@@ -522,10 +522,12 @@
             "the mutable_tree attribute of that object.", (2, 0))
         self.add_hook('pre_transform',
             "Called before a tree transform on this tree. The hook is called "
-            "with the tree transform is being done.", (2, 5))
+            "with the tree that is being transformed and the transform.",
+            (2, 5))
         self.add_hook('post_transform',
             "Called after a tree transform has been performed on a tree. "
-            "The hook is called with the tree transform that is being done.",
+            "The hook is called with the tree that is being transformed and "
+            "the transform.",
             (2, 5))
 
 

=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2011-11-17 13:45:49 +0000
+++ bzrlib/tests/test_transform.py	2012-01-06 01:58:27 +0000
@@ -60,6 +60,7 @@
     pathjoin,
 )
 from bzrlib.merge import Merge3Merger, Merger
+from bzrlib.mutabletree import MutableTree
 from bzrlib.tests import (
     features,
     TestCaseInTempDir,
@@ -3717,3 +3718,40 @@
                          remaining_conflicts.pop())
         self.assertLength(1, warnings)
         self.assertStartsWith(warnings[0], 'donttouchmypreciouuus')
+
+
+class TestTransformHooks(tests.TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestTransformHooks, self).setUp()
+        self.wt = self.make_branch_and_tree('.')
+        os.chdir('..')
+
+    def get_transform(self):
+        transform = TreeTransform(self.wt)
+        self.addCleanup(transform.finalize)
+        return transform, transform.root
+
+    def test_pre_commit_hooks(self):
+        calls = []
+        def record_pre_transform(tree, tt):
+            calls.append((tree, tt))
+        MutableTree.hooks.install_named_hook('pre_transform',
+            record_pre_transform, "Pre transform")
+        transform, root = self.get_transform()
+        old_root_id = transform.tree_file_id(root)
+        transform.apply()
+        self.assertEqual(old_root_id, self.wt.get_root_id())
+        self.assertEquals([(self.wt, transform)], calls)
+
+    def test_post_commit_hooks(self):
+        calls = []
+        def record_post_transform(tree, tt):
+            calls.append((tree, tt))
+        MutableTree.hooks.install_named_hook('post_transform',
+            record_post_transform, "Post transform")
+        transform, root = self.get_transform()
+        old_root_id = transform.tree_file_id(root)
+        transform.apply()
+        self.assertEqual(old_root_id, self.wt.get_root_id())
+        self.assertEquals([(self.wt, transform)], calls)

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2012-01-06 01:42:16 +0000
+++ bzrlib/transform.py	2012-01-06 01:58:27 +0000
@@ -50,6 +50,7 @@
                            ExistingLimbo, ImmortalLimbo, NoFinalPath,
                            UnableCreateSymlink)
 from bzrlib.filters import filtered_output_bytes, ContentFilterContext
+from bzrlib.mutabletree import MutableTree
 from bzrlib.osutils import (
     delete_any,
     file_kind,
@@ -156,7 +157,7 @@
         if self._tree is None:
             return
         for hook in MutableTree.hooks['post_transform']:
-            hook(self)
+            hook(self._tree, self)
         self._tree.unlock()
         self._tree = None
 
@@ -1724,7 +1725,7 @@
         :param _mover: Supply an alternate FileMover, for testing
         """
         for hook in MutableTree.hooks['pre_transform']:
-            hook(self)
+            hook(self._tree, self)
         if not no_conflicts:
             self._check_malformed()
         child_pb = ui.ui_factory.nested_progress_bar()

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2012-01-05 16:03:11 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2012-01-06 01:58:27 +0000
@@ -178,6 +178,10 @@
   which contains the branch from which the ``other_tree``
   was obtained, if any. (Jelmer Vernooij)
 
+* ``MutableTree`` has two new hooks ``pre_transform`` and
+  ``post_transform`` that are called for tree transform operations.
+  (Jelmer Vernooij, #912084)
+
 * New HPSS call ``BzrDir.checkout_metadir``. (Jelmer Vernooij, #894459)
 
 * New HPSS call ``VersionedFileRepository.get_inventories``,

